@@ -46,7 +46,9 @@ def t_test(data: pd.DataFrame, unit_col: str, variant_col: str, metrics: list[st
     stats = means.merge(vars, on=[variant_col, "metric"]).merge(counts, on=[variant_col, "metric"])
     stats["std"] = np.sqrt(stats["var"])
     stats["stderr"] = np.sqrt(stats["var"] / stats["count"])
-    stats = stats.merge(stats.query(f"{variant_col} == 1"), on="metric", suffixes=["", "_c"]).drop("variant_c", axis=1)
+    stats = stats.merge(stats.query(f"{variant_col} == 1"), on="metric", suffixes=["", "_c"]).drop(
+        f"{variant_col}_c", axis=1
+    )
 
     stats["abs_diff_mean"] = stats["mean"] - stats["mean_c"]
     stats["abs_diff_std"] = np.sqrt(stats["stderr"] ** 2 + stats["stderr_c"] ** 2)
